@@ -8,7 +8,7 @@ use Errno qw(EAGAIN);
 
 use vars qw($VERSION);
 BEGIN {
-	$VERSION = "2.3_2";
+	$VERSION = "2.2";
 }
 
 my $BLOCKSIZE = 65536;
@@ -27,7 +27,7 @@ my @urlencode_valid;
 foreach my $char (split('', $URLENCODE_VALID)) {
   $urlencode_valid[ord $char]=$char;
 }
-for (my $n=0;$n<256;$n++) {
+for (my $n=0;$n<255;$n++) {
   if (!defined($urlencode_valid[$n])) {
     $urlencode_valid[$n]=sprintf("%%%02X", $n);
   }
@@ -139,7 +139,7 @@ sub request
 
   # Parse URL 
   my ($protocol,$host,$junk,$port,$object) = 
-    $url =~ m{^([^:/]+)://([^/:]*)(:(\d+))?(/?.*)$};
+    $url =~ m{^([^:/]+)://([^/:]*)(:(\d+))?(/.*)$};
 
   # Only HTTP is supported here
   if ($protocol ne "http")
@@ -446,7 +446,6 @@ sub add_req_header
   my $self = shift;
   my ($header, $value) = @_;
   
-  return unless defined($value);
   my $lcheader = lc($header);
   $self->{DEBUG} && $self->DEBUG("add_req_header $header $value");
   ${$self->{headers}}{$lcheader} = $value;
@@ -612,13 +611,11 @@ sub http_write
   }
 
   my $size = length($line);
-  my $total_sent = 0;
-  my $nbytes;
-  do {
-    $nbytes = syswrite($fh, $line, $size - $total_sent, $total_sent );
-    die $! unless(defined($nbytes) || $!{EAGAIN}); # non-recoverable error occured! 
-    $total_sent += $nbytes;
-  } while ($total_sent < $size);
+  my $bytes = syswrite($fh, $line, length($line) , 0 );  # please double check new length limit
+                                                         # is this ok?
+  while ( ($size - $bytes) > 0) {
+    $bytes += syswrite($fh, $line, length($line)-$bytes, $bytes );  # also here
+  }
 }
  
 sub http_read
@@ -769,38 +766,38 @@ HTTP::Lite - Lightweight HTTP implementation
 =head1 SYNOPSIS
 
     use HTTP::Lite;
-    $http = HTTP::Lite->new;
+    $http = new HTTP::Lite;
     $req = $http->request("http://www.cpan.org/") 
         or die "Unable to get document: $!";
     print $http->body();
 
 =head1 DESCRIPTION
 
-HTTP::Lite is a stand-alone lightweight HTTP/1.1 implementation
-for perl.  It is not intended as a replacement for the
-fully-featured LWP module.  Instead, it is intended for use in
-situations where it is desirable to install the minimal number of
-modules to achieve HTTP support, or where LWP is not a good
-candidate due to CPU overhead, such as slower processors.
-HTTP::Lite is also significantly faster than LWP.
+    HTTP::Lite is a stand-alone lightweight HTTP/1.1 implementation
+    for perl.  It is not intended as a replacement for the
+    fully-features LWP module.  Instead, it is intended for use in
+    situations where it is desirable to install the minimal number of
+    modules to achieve HTTP support, or where LWP is not a good
+    candidate due to CPU overhead, such as slower processors.
+    HTTP::Lite is also significantly faster than LWP.
 
-HTTP::Lite is ideal for CGI (or mod_perl) programs or for bundling
-for redistribution with larger packages where only HTTP GET and
-POST functionality are necessary.
+    HTTP::Lite is ideal for CGI (or mod_perl) programs or for bundling
+    for redistribution with larger packages where only HTTP GET and
+    POST functionality are necessary.
 
-HTTP::Lite supports basic POST and GET operations only.  As of
-0.2.1, HTTP::Lite supports HTTP/1.1 and is compliant with the Host
-header, necessary for name based virtual hosting.  Additionally,
-HTTP::Lite now supports Proxies.
+    HTTP::Lite supports basic POST and GET operations only.  As of
+    0.2.1, HTTP::Lite supports HTTP/1.1 and is compliant with the Host
+    header, necessary for name based virtual hosting.  Additionally,
+    HTTP::Lite now supports Proxies.
 
-As of 2.0.0 HTTP::Lite now supports a callback to allow processing
-of request data as it arrives.  This is useful for handling very
-large files without consuming memory.
+    As of 2.0.0 HTTP::Lite now supports a callback to allow processing
+    of request data as it arrives.  This is useful for handling very
+    large files without consuming memory.
 
-If you require more functionality, such as FTP or HTTPS, please
-see libwwwperl (LWP).  LWP is a significantly better and more
-comprehensive package than HTTP::Lite, and should be used instead
-of HTTP::Lite whenever possible.
+    If you require more functionality, such as FTP or HTTPS, please
+    see libwwwperl (LWP).  LWP is a significantly better and more
+    comprehensive package than HTTP::Lite, and should be used instead
+    of HTTP::Lite whenever possible.
 
 =head1 CONSTRUCTOR
 
@@ -853,7 +850,7 @@ An example use to save a document to file is:
   }
 
   $url = "$testpath/bigbinary.dat";
-  open OUT, '>','bigbinary.dat';
+  open OUT, ">bigbinary.dat";
   $res = $http->request($url, \&savetofile, OUT);
   close OUT;
 
@@ -871,18 +868,18 @@ The current phases are:
 
   connect - connection has been established and headers are being
             transmitted.
-
+            
   content-length - return value is used as the content-length.  If undef,
             and prepare_post() was used, the content length is
             calculated.
-
+                   
   done-headers - all headers have been sent
-
+  
   content - return value is used as content and is sent to client.  Return
             undef to use the internal content defined by prepare_post().
-
+            
   content-done - content has been successfuly transmitted.
-
+  
   data - A block of data has been received.  The data is referenced by
             $dataref.  The return value is dereferenced and replaces the
             content passed in.  Return undef to avoid using memory for large
@@ -908,19 +905,16 @@ broken HTTP/1.1 servers.  Use 1 to enable HTTP/1.1 support.
 
 =item delete_req_header ( $header )
 
-Add, Delete, or get a HTTP header(s) for the request.  These functions
+Add, Delete, or a HTTP header(s) for the request.  These functions
 allow you to override any header.  Presently, Host, User-Agent,
 Content-Type, Accept, and Connection are pre-defined by the HTTP::Lite
 module.  You may not override Host, Connection, or Accept.
 
-If you call C<add_req_header()> with C<$value> set to C<undef>,
-then the header won't be added.
-
 To provide (proxy) authentication or authorization, you would use:
 
     use HTTP::Lite;
     use MIME::Base64;
-    $http = HTTP::Lite->new;
+    $http = new HTTP::Lite;
     $encoded = encode_base64('username:password');
     $http->add_req_header("Authorization", $encoded);
 
@@ -982,7 +976,7 @@ choose.
 
 =item local_port ( $port )
 
-Explicity select the local port.  0 (default and recommended) lets the
+Explicity select the local port.  0 (default and reccomended) lets the
 system choose.
 
 =item method ( $method )
@@ -996,7 +990,7 @@ setting.  Usual choices are GET, POST, PUT, HEAD
 
     # Get and print out the headers and body of the CPAN homepage
     use HTTP::Lite;
-    $http = HTTP::Lite->new;
+    $http = new HTTP::Lite;
     $req = $http->request("http://www.cpan.org/")
         or die "Unable to get document: $!";
     die "Request failed ($req): ".$http->status_message()
@@ -1012,7 +1006,7 @@ setting.  Usual choices are GET, POST, PUT, HEAD
 
     # POST a query to the dejanews USENET search engine
     use HTTP::Lite;
-    $http = HTTP::Lite->new;
+    $http = new HTTP::Lite;
     %vars = (
              "QRY" => "perl",
              "ST" => "MS",
@@ -1034,19 +1028,17 @@ setting.  Usual choices are GET, POST, PUT, HEAD
     - Redirects (Location) are not automatically followed
     - multipart/form-data POSTs are not directly supported (necessary
       for File uploads).
-
+    
 =head1 BUGS
 
-Some broken HTTP/1.1 servers send incorrect chunk sizes when transferring files.
-HTTP/1.1 mode is now disabled by default.
+    Some broken HTTP/1.1 servers send incorrect chunk sizes
+    when transferring files.  HTTP/1.1 mode is now disabled by
+    default.
 
 =head1 AUTHOR
 
 Roy Hooper <rhooper@thetoybox.org>
 
-Now co-maintained by Neil Bowers E<lt>neilb@cpan.orgE<gt>.
-This is a developer release after fixing some bugs, before doing a regular release.
-
 =head1 SEE ALSO
 
 L<LWP>
@@ -1056,7 +1048,7 @@ RFC 2068 - HTTP/1.1 -http://www.w3.org/
 
 Copyright (c) 2000-2002 Roy Hooper.  All rights reserved.
 
-Some parts copyright 2009 - 2010 Adam Kennedy.
+Some parts copyright 2009 Adam Kennedy.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
